@@ -1,4 +1,3 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 
 /* eel-stock-dialogs.h: Various standard dialogs for Eel.
 
@@ -21,8 +20,7 @@
    Authors: Darin Adler <darin@eazel.com>
 */
 
-#ifndef EEL_STOCK_DIALOGS_H
-#define EEL_STOCK_DIALOGS_H
+#pragma once
 
 #include <gtk/gtk.h>
 
@@ -74,6 +72,4 @@ GtkDialog *eel_create_question_dialog         (const char        *primary_text,
 					       int                response_one,
 					       const char        *answer_two,
 					       int                response_two,
-					       GtkWindow         *parent);
-
-#endif /* EEL_STOCK_DIALOGS_H */
+					       GtkWindow         *parent);
\ No newline at end of file
