@@ -34,6 +34,7 @@
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
+#include <libhandy-1/handy.h>
 #include <nautilus-extension.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -938,7 +939,7 @@ nautilus_application_handle_file_args (NautilusApplication *self,
     GFile **files;
     GFile *file;
     gint idx, len;
-    const gchar * const *remaining = NULL;
+    g_autofree const gchar **remaining = NULL;
     GPtrArray *file_array;
 
     g_variant_dict_lookup (options, G_OPTION_REMAINING, "^a&s", &remaining);
@@ -1259,20 +1260,6 @@ update_previewer_selection (NautilusApplication *self,
     }
 }
 
-static void
-on_application_active_window_changed (NautilusApplication *self,
-                                      GParamSpec          *pspec,
-                                      gpointer             user_data)
-{
-    GtkWindow *window;
-
-    window = gtk_application_get_active_window (GTK_APPLICATION (self));
-    if (NAUTILUS_IS_WINDOW (window))
-    {
-        update_previewer_selection (self, NAUTILUS_WINDOW (window));
-    }
-}
-
 static void
 on_application_shutdown (GApplication *application,
                          gpointer      user_data)
@@ -1326,6 +1313,8 @@ nautilus_application_startup_common (NautilusApplication *self)
      */
     G_APPLICATION_CLASS (nautilus_application_parent_class)->startup (G_APPLICATION (self));
 
+    hdy_init ();
+
     gtk_window_set_default_icon_name (APPLICATION_ID);
 
     setup_theme_extensions ();
@@ -1355,7 +1344,6 @@ nautilus_application_startup_common (NautilusApplication *self)
 
     nautilus_profile_end (NULL);
 
-    g_signal_connect (self, "notify::active-window", G_CALLBACK (on_application_active_window_changed), NULL);
     g_signal_connect (self, "shutdown", G_CALLBACK (on_application_shutdown), NULL);
 
     g_signal_connect_object (gtk_icon_theme_get_default (),
