@@ -17,24 +17,24 @@
  *  Author: Anders Carlsson <andersca@imendio.com>
  */
 
-#include <config.h>
 #include "nautilus-search-directory.h"
-#include "nautilus-search-directory-file.h"
-
-#include "nautilus-directory-private.h"
-#include "nautilus-file.h"
-#include "nautilus-file-private.h"
-#include "nautilus-file-utilities.h"
-#include "nautilus-search-provider.h"
-#include "nautilus-search-engine.h"
-#include "nautilus-search-engine-model.h"
 
 #include <eel/eel-glib-extensions.h>
-#include <gtk/gtk.h>
 #include <gio/gio.h>
+#include <gtk/gtk.h>
 #include <string.h>
 #include <sys/time.h>
 
+#include "nautilus-directory-private.h"
+#include "nautilus-file-private.h"
+#include "nautilus-file-utilities.h"
+#include "nautilus-file.h"
+#include "nautilus-query.h"
+#include "nautilus-search-directory-file.h"
+#include "nautilus-search-engine-model.h"
+#include "nautilus-search-engine.h"
+#include "nautilus-search-provider.h"
+
 struct _NautilusSearchDirectory
 {
     NautilusDirectory parent_instance;
@@ -182,8 +182,6 @@ static void
 start_search (NautilusSearchDirectory *self)
 {
     NautilusSearchEngineModel *model_provider;
-    NautilusSearchEngineSimple *simple_provider;
-    gboolean recursive;
 
     if (!self->query)
     {
@@ -211,10 +209,6 @@ start_search (NautilusSearchDirectory *self)
     model_provider = nautilus_search_engine_get_model_provider (self->engine);
     nautilus_search_engine_model_set_model (model_provider, self->base_model);
 
-    simple_provider = nautilus_search_engine_get_simple_provider (self->engine);
-    recursive = nautilus_query_get_recursive (self->query);
-    g_object_set (simple_provider, "recursive", recursive, NULL);
-
     reset_file_list (self);
 
     nautilus_search_provider_start (NAUTILUS_SEARCH_PROVIDER (self->engine));
